"""
Python module generated from Java source file com.google.common.collect.BaseImmutableMultimap

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class BaseImmutableMultimap(AbstractMultimap):
    """
    A dummy superclass of ImmutableMultimap that can be instanceof'd without ProGuard
    retaining additional implementation details of ImmutableMultimap.
    """


