"""
Python module generated from Java source file org.bukkit.boss.KeyedBossBar

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Keyed
from org.bukkit.boss import *
from typing import Any, Callable, Iterable, Tuple


class KeyedBossBar(BossBar, Keyed):
    """
    Represents a custom BossBar that has a
    org.bukkit.NamespacedKey
    """


